@@ -13,4 +13,12 @@
 # the License.
 
 """napalm_eos package."""
-from eos import EOSDriver
+from napalm_eos.eos import EOSDriver
+import pkg_resources
+
+try:
+    __version__ = pkg_resources.get_distribution('napalm-eos').version
+except pkg_resources.DistributionNotFound:
+    __version__ = "Not installed"
+
+__all__ = ('EOSDriver',)
