@@ -43,6 +43,7 @@ from napalm_base.utils import py23_compat
 from napalm_base.exceptions import ConnectionException, MergeConfigException, \
                         ReplaceConfigException, SessionLockedException, CommandErrorException
 
+import napalm_base.constants as c
 # local modules
 # here add local imports
 # e.g. import napalm_eos.helpers etc.
@@ -427,7 +428,7 @@ class EOSDriver(NetworkDriver):
     def get_environment(self):
         def extract_temperature_data(data):
             for s in data:
-                temp = s['currentTemperature']
+                temp = s['currentTemperature'] if 'currentTemperature' in s else 0.0
                 name = s['name']
                 values = {
                    'temperature': temp,
@@ -483,7 +484,7 @@ class EOSDriver(NetworkDriver):
         # Matches either of
         # Mem:   3844356k total,  3763184k used,    81172k free,    16732k buffers ( 4.16 > )
         # KiB Mem:  32472080 total,  5697604 used, 26774476 free,   372052 buffers ( 4.16 < )
-        mem_regex = '.*total,\s+ (?P<used>\d+)[k\s]+used,\s+(?P<free>\d+)[k\s]+free,.*'
+        mem_regex = '.*total,\s+(?P<used>\d+)[k\s]+used,\s+(?P<free>\d+)[k\s]+free,.*'
         m = re.match(mem_regex, cpu_lines[3])
         environment_counters['memory'] = {
             'available_ram': int(m.group('free')),
@@ -540,7 +541,7 @@ class EOSDriver(NetworkDriver):
                 )
         return lldp_neighbors_out
 
-    def cli(self, commands=None):
+    def cli(self, commands):
         cli_output = dict()
 
         if type(commands) is not list:
@@ -985,6 +986,9 @@ class EOSDriver(NetworkDriver):
     def get_route_to(self, destination='', protocol=''):
         routes = dict()
 
+        if protocol.lower() == 'direct':
+            protocol = 'connected'
+
         try:
             ipv = ''
             if IPNetwork(destination).version == 6:
@@ -992,9 +996,10 @@ class EOSDriver(NetworkDriver):
         except AddrFormatError:
             return 'Please specify a valid destination!'
 
-        command = 'show ip{ipv} route {destination} detail'.format(
+        command = 'show ip{ipv} route {destination} {protocol} detail'.format(
             ipv=ipv,
-            destination=destination
+            destination=destination,
+            protocol=protocol,
         )
 
         command_output = self.device.run_commands([command])[0]
@@ -1008,7 +1013,7 @@ class EOSDriver(NetworkDriver):
             if prefix not in routes.keys():
                 routes[prefix] = list()
             route_protocol = route_details.get('routeType').upper()
-            preference = route_details.get('preference')
+            preference = route_details.get('preference', 0)
 
             route = {
                 'current_active': False,
@@ -1066,12 +1071,20 @@ class EOSDriver(NetworkDriver):
             else:
                 for next_hop in route_details.get('vias'):
                     route_next_hop = route.copy()
-                    route_next_hop.update(
-                        {
-                            'next_hop': napalm_base.helpers.ip(next_hop.get('nexthopAddr')),
-                            'outgoing_interface': next_hop.get('interface')
-                        }
-                    )
+                    if next_hop.get('nexthopAddr') is None:
+                        route_next_hop.update(
+                            {
+                                'next_hop': '',
+                                'outgoing_interface': next_hop.get('interface')
+                            }
+                        )
+                    else:
+                        route_next_hop.update(
+                            {
+                                'next_hop': napalm_base.helpers.ip(next_hop.get('nexthopAddr')),
+                                'outgoing_interface': next_hop.get('interface')
+                            }
+                        )
                     routes[prefix].append(route_next_hop)
 
         return routes
@@ -1134,7 +1147,11 @@ class EOSDriver(NetworkDriver):
 
         return users
 
-    def traceroute(self, destination, source='', ttl=0, timeout=0):
+    def traceroute(self,
+                   destination,
+                   source=c.TRACEROUTE_SOURCE,
+                   ttl=c.TRACEROUTE_TTL,
+                   timeout=c.TRACEROUTE_TIMEOUT):
 
         _HOP_ENTRY_PROBE = [
             '\s+',
@@ -1541,7 +1558,8 @@ class EOSDriver(NetworkDriver):
         else:
             return vrfs
 
-    def ping(self, destination, source='', ttl=255, timeout=2, size=100, count=5):
+    def ping(self, destination, source=c.PING_SOURCE, ttl=c.PING_TTL, timeout=c.PING_TIMEOUT,
+             size=c.PING_SIZE, count=c.PING_COUNT):
         """
         Execute ping on the device and returns a dictionary with the result.
         Output dictionary has one of following keys:
